'use strict';
Object.defineProperty(exports, '__esModule', { value: true });
var ServiceLocator = /** @class */ (function () {
  function ServiceLocator() {
    this.dependencies = {};
    this.singletons = {};
  }
  ServiceLocator.getInstance = function () {
    if (!ServiceLocator.instance) {
      ServiceLocator.instance = new ServiceLocator();
    }
    return ServiceLocator.instance;
  };
  ServiceLocator.prototype.register = function (dependencyName, dependency, lazy) {
    if (lazy === void 0) {
      lazy = false;
    }
    this.dependencies[dependencyName] = dependency;
    if (!lazy) {
      this.singletons[dependencyName] = dependency();
    }
  };
  ServiceLocator.prototype.resolve = function (dependencyName) {
    if (!this.dependencies[dependencyName]) {
      throw new Error('Dependency not found: '.concat(dependencyName));
    }
    if (!this.singletons[dependencyName]) {
      this.singletons[dependencyName] = this.dependencies[dependencyName]();
    }
    return this.singletons[dependencyName];
  };
  ServiceLocator.prototype.reset = function () {
    this.dependencies = {};
    this.singletons = {};
  };
  return ServiceLocator;
})();
exports.default = ServiceLocator;
