'use strict';
Object.defineProperty(exports, '__esModule', { value: true });
var ServiceLocator_1 = require('../ServiceLocator');
var DependencyA = /** @class */ (function () {
  function DependencyA() {
    this.name = 'DependencyA';
  }
  return DependencyA;
})();
var DependencyB = /** @class */ (function () {
  function DependencyB(dependencyA) {
    this.dependencyA = dependencyA;
    this.name = 'DependencyB';
  }
  return DependencyB;
})();
var DependencyC = /** @class */ (function () {
  function DependencyC(dependencyB) {
    this.dependencyB = dependencyB;
    this.name = 'DependencyC';
  }
  return DependencyC;
})();
describe('ServiceLocator', function () {
  beforeEach(function () {
    ServiceLocator_1.default.getInstance().reset();
  });
  it('should register and resolve non-lazy singletons', function () {
    ServiceLocator_1.default.getInstance().register('DependencyA', function () {
      return new DependencyA();
    });
    var dependencyA1 = ServiceLocator_1.default.getInstance().resolve('DependencyA');
    var dependencyA2 = ServiceLocator_1.default.getInstance().resolve('DependencyA');
    expect(dependencyA1).toBeInstanceOf(DependencyA);
    expect(dependencyA2).toBeInstanceOf(DependencyA);
    expect(dependencyA1).toBe(dependencyA2);
  });
  it('should register and resolve lazy dependencies', function () {
    ServiceLocator_1.default.getInstance().register(
      'DependencyA',
      function () {
        return new DependencyA();
      },
      true,
    );
    var dependencyA1 = ServiceLocator_1.default.getInstance().resolve('DependencyA');
    var dependencyA2 = ServiceLocator_1.default.getInstance().resolve('DependencyA');
    expect(dependencyA1).toBeInstanceOf(DependencyA);
    expect(dependencyA2).toBeInstanceOf(DependencyA);
    expect(dependencyA1).toBe(dependencyA2);
  });
  it('should resolve chain dependencies', function () {
    ServiceLocator_1.default.getInstance().register('DependencyA', function () {
      return new DependencyA();
    });
    ServiceLocator_1.default.getInstance().register('DependencyB', function () {
      return new DependencyB(ServiceLocator_1.default.getInstance().resolve('DependencyA'));
    });
    ServiceLocator_1.default.getInstance().register('DependencyC', function () {
      return new DependencyC(ServiceLocator_1.default.getInstance().resolve('DependencyB'));
    });
    var dependencyC = ServiceLocator_1.default.getInstance().resolve('DependencyC');
    expect(dependencyC).toBeInstanceOf(DependencyC);
    expect(dependencyC.dependencyB).toBeInstanceOf(DependencyB);
    expect(dependencyC.dependencyB.dependencyA).toBeInstanceOf(DependencyA);
  });
});
